using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;

namespace Classless.MXO.Blipper {
	/// <summary>Summary description for FrmAddEditBlip.</summary>
	public class FrmAddEditBlip : Form {
		#region Control Declarations
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.Button btnOK;
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.TextBox txtName;
		private System.Windows.Forms.Label label1;
		private System.Windows.Forms.Label label2;
		private System.Windows.Forms.Label label3;
		private System.Windows.Forms.TextBox txtCoordX;
		private System.Windows.Forms.Label label4;
		private System.Windows.Forms.TextBox txtCoordY;
		private System.Windows.Forms.Label label5;
		private System.Windows.Forms.TextBox txtCoordZ;
		private System.Windows.Forms.ComboBox comboDistrict;
		private System.ComponentModel.Container components = null;
		#endregion


		private double _x;
		private double _y;
		private double _z;


		/// <summary>Gets the name that was entered by the user.</summary>
		public string BlipName {
			get { return txtName.Text; }
		}

		/// <summary>Gets the district that was entered by the user.</summary>
		public DistrictType District {
			get { return (DistrictType)Enum.Parse(typeof(DistrictType), comboDistrict.Text, false); }
		}

		/// <summary>Gets the X coordinate that was entered by the user.</summary>
		public double X {
			get { return _x; }
		}

		/// <summary>Gets the Y coordinate that was entered by the user.</summary>
		public double Y {
			get { return _y; }
		}

		/// <summary>Gets the Z coordinate that was entered by the user.</summary>
		public double Z {
			get { return _z; }
		}


		/// <summary>Initializes a new instance of FrmAddEditBlip.</summary>
		public FrmAddEditBlip() {
			init();
			this.Text = "Add a Blip";
		}

		/// <summary>Initializes a new instance of FrmAddEditBlip.</summary>
		/// <param name="b">The blip we want to edit.</param>
		public FrmAddEditBlip(Blip b) {
			init();
			this.Text = "Edit a Blip";

			txtName.Text = b.Name;
			comboDistrict.Text = b.District.ToString();
			txtCoordX.Text = b.X.ToString();
			txtCoordY.Text = b.Y.ToString();
			txtCoordZ.Text = b.Z.ToString();
		}


		/// <summary>Initializes the form.</summary>
		private void init() {
			InitializeComponent();
			StartEventProcessing();

			// Set up the fields.
			txtName.MaxLength = ushort.MaxValue;
			foreach (string dt in Enum.GetNames(typeof(DistrictType))) {
				comboDistrict.Items.Add(dt);
			}
			comboDistrict.Text = DistrictType.RichlandWestview.ToString();
		}


		/// <summary>Clean up any resources being used.</summary>
		protected override void Dispose(bool disposing) {
			if ((disposing) && (components != null)) {
				components.Dispose();
			}
			base.Dispose(disposing);
		}


		#region Events
		// Hook into the event processing.
		private void StartEventProcessing() {
			btnOK.Click += new EventHandler(btnOK_Click);
			btnCancel.Click += new EventHandler(btnCancel_Click);
		}

		// User accepts the values that were entered.
		private void btnOK_Click(object sender, EventArgs e) {
			try {
				_x = double.Parse(txtCoordX.Text);
			} catch {
				MessageBox.Show("The value '" + txtCoordX.Text + "' is not a valid X coordinate.", "Invalid Coordinate");
				return;
			}

			try {
				_y = double.Parse(txtCoordY.Text);
			} catch {
				MessageBox.Show("The value '" + txtCoordY.Text + "' is not a valid Y coordinate.", "Invalid Coordinate");
				return;
			}

			try {
				_z = double.Parse(txtCoordZ.Text);
			} catch {
				MessageBox.Show("The value '" + txtCoordZ.Text + "' is not a valid Z coordinate.", "Invalid Coordinate");
				return;
			}

			this.DialogResult = DialogResult.OK;
			this.Close();
		}

		// User is cancelling the operation.
		private void btnCancel_Click(object sender, EventArgs e) {
			this.DialogResult = DialogResult.Cancel;
			this.Close();
		}
		#endregion


		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.comboDistrict = new System.Windows.Forms.ComboBox();
			this.label5 = new System.Windows.Forms.Label();
			this.txtCoordZ = new System.Windows.Forms.TextBox();
			this.label4 = new System.Windows.Forms.Label();
			this.txtCoordY = new System.Windows.Forms.TextBox();
			this.label3 = new System.Windows.Forms.Label();
			this.txtCoordX = new System.Windows.Forms.TextBox();
			this.label2 = new System.Windows.Forms.Label();
			this.label1 = new System.Windows.Forms.Label();
			this.txtName = new System.Windows.Forms.TextBox();
			this.btnOK = new System.Windows.Forms.Button();
			this.btnCancel = new System.Windows.Forms.Button();
			this.groupBox1.SuspendLayout();
			this.SuspendLayout();
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.comboDistrict);
			this.groupBox1.Controls.Add(this.label5);
			this.groupBox1.Controls.Add(this.txtCoordZ);
			this.groupBox1.Controls.Add(this.label4);
			this.groupBox1.Controls.Add(this.txtCoordY);
			this.groupBox1.Controls.Add(this.label3);
			this.groupBox1.Controls.Add(this.txtCoordX);
			this.groupBox1.Controls.Add(this.label2);
			this.groupBox1.Controls.Add(this.label1);
			this.groupBox1.Controls.Add(this.txtName);
			this.groupBox1.Location = new System.Drawing.Point(4, 4);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(468, 112);
			this.groupBox1.TabIndex = 0;
			this.groupBox1.TabStop = false;
			this.groupBox1.Text = "Blip Information:";
			// 
			// comboDistrict
			// 
			this.comboDistrict.DropDownStyle = System.Windows.Forms.ComboBoxStyle.DropDownList;
			this.comboDistrict.Location = new System.Drawing.Point(52, 52);
			this.comboDistrict.Name = "comboDistrict";
			this.comboDistrict.Size = new System.Drawing.Size(116, 21);
			this.comboDistrict.TabIndex = 3;
			// 
			// label5
			// 
			this.label5.Location = new System.Drawing.Point(320, 80);
			this.label5.Name = "label5";
			this.label5.Size = new System.Drawing.Size(26, 20);
			this.label5.TabIndex = 8;
			this.label5.Text = "Z:";
			this.label5.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// txtCoordZ
			// 
			this.txtCoordZ.Location = new System.Drawing.Point(348, 80);
			this.txtCoordZ.Name = "txtCoordZ";
			this.txtCoordZ.Size = new System.Drawing.Size(112, 20);
			this.txtCoordZ.TabIndex = 9;
			this.txtCoordZ.Text = "";
			// 
			// label4
			// 
			this.label4.Location = new System.Drawing.Point(172, 80);
			this.label4.Name = "label4";
			this.label4.Size = new System.Drawing.Size(26, 20);
			this.label4.TabIndex = 6;
			this.label4.Text = "Y:";
			this.label4.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// txtCoordY
			// 
			this.txtCoordY.Location = new System.Drawing.Point(200, 80);
			this.txtCoordY.Name = "txtCoordY";
			this.txtCoordY.Size = new System.Drawing.Size(112, 20);
			this.txtCoordY.TabIndex = 7;
			this.txtCoordY.Text = "";
			// 
			// label3
			// 
			this.label3.Location = new System.Drawing.Point(24, 80);
			this.label3.Name = "label3";
			this.label3.Size = new System.Drawing.Size(26, 20);
			this.label3.TabIndex = 4;
			this.label3.Text = "X:";
			this.label3.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// txtCoordX
			// 
			this.txtCoordX.Location = new System.Drawing.Point(52, 80);
			this.txtCoordX.Name = "txtCoordX";
			this.txtCoordX.Size = new System.Drawing.Size(112, 20);
			this.txtCoordX.TabIndex = 5;
			this.txtCoordX.Text = "";
			// 
			// label2
			// 
			this.label2.Location = new System.Drawing.Point(8, 52);
			this.label2.Name = "label2";
			this.label2.Size = new System.Drawing.Size(44, 20);
			this.label2.TabIndex = 2;
			this.label2.Text = "District:";
			this.label2.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// label1
			// 
			this.label1.Location = new System.Drawing.Point(8, 24);
			this.label1.Name = "label1";
			this.label1.Size = new System.Drawing.Size(44, 20);
			this.label1.TabIndex = 1;
			this.label1.Text = "Name:";
			this.label1.TextAlign = System.Drawing.ContentAlignment.MiddleRight;
			// 
			// txtName
			// 
			this.txtName.Location = new System.Drawing.Point(52, 24);
			this.txtName.Name = "txtName";
			this.txtName.Size = new System.Drawing.Size(408, 20);
			this.txtName.TabIndex = 0;
			this.txtName.Text = "";
			// 
			// btnOK
			// 
			this.btnOK.Location = new System.Drawing.Point(316, 120);
			this.btnOK.Name = "btnOK";
			this.btnOK.TabIndex = 1;
			this.btnOK.Text = "&OK";
			// 
			// btnCancel
			// 
			this.btnCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.btnCancel.Location = new System.Drawing.Point(396, 120);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.TabIndex = 2;
			this.btnCancel.Text = "&Cancel";
			// 
			// FrmAddEditBlip
			// 
			this.AcceptButton = this.btnOK;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.btnCancel;
			this.ClientSize = new System.Drawing.Size(478, 147);
			this.Controls.Add(this.btnCancel);
			this.Controls.Add(this.btnOK);
			this.Controls.Add(this.groupBox1);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.MaximizeBox = false;
			this.MinimizeBox = false;
			this.Name = "FrmAddEditBlip";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.groupBox1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion
	}
}
